@@ -4,9 +4,9 @@ from pathlib import Path
 from pymatgen import Spin
 from pymatgen.io.vasp.outputs import Vasprun
 
-from ifermi.fermi_surface import FermiSurface
-from ifermi.interpolator import Interpolator
-from ifermi.plotter import FermiSurfacePlotter, save_plot
+from ifermi.interpolate import FourierInterpolator
+from ifermi.plot import FermiSurfacePlotter, save_plot
+from ifermi.surface import FermiSurface
 
 test_dir = Path(__file__).resolve().parent
 root_dir = test_dir / "../.."
@@ -21,9 +21,9 @@ class IntegrationTest(unittest.TestCase):
         self.output_file = test_dir / "fs.png"
 
     def test_integration_wigner_seitz(self):
-        interpolator = Interpolator(self.band_structure)
-        new_bs, kpoint_dim = interpolator.interpolate_bands(1)
-        fs = FermiSurface.from_band_structure(new_bs, kpoint_dim)
+        interpolator = FourierInterpolator(self.band_structure)
+        new_bs = interpolator.interpolate_bands(1)
+        fs = FermiSurface.from_band_structure(new_bs)
         plotter = FermiSurfacePlotter(fs)
         plot = plotter.get_plot(plot_type="matplotlib")
         save_plot(plot, self.output_file)
@@ -31,9 +31,9 @@ class IntegrationTest(unittest.TestCase):
         # plotter.plot(plot_type='mayavi', interactive=False, filename=self.output_file)
 
     def test_integration_reciprocal(self):
-        interpolator = Interpolator(self.band_structure)
-        new_bs, kpoint_dim = interpolator.interpolate_bands(1)
-        fs = FermiSurface.from_band_structure(new_bs, kpoint_dim, wigner_seitz=False)
+        interpolator = FourierInterpolator(self.band_structure)
+        new_bs = interpolator.interpolate_bands(1)
+        fs = FermiSurface.from_band_structure(new_bs, wigner_seitz=False)
         plotter = FermiSurfacePlotter(fs)
         plot = plotter.get_plot(plot_type="matplotlib")
         save_plot(plot, self.output_file)
@@ -41,9 +41,9 @@ class IntegrationTest(unittest.TestCase):
         # plotter.plot(plot_type='mayavi', interactive=False, filename=self.output_file)
 
     def test_integration_spin(self):
-        interpolator = Interpolator(self.band_structure)
-        new_bs, kpoint_dim = interpolator.interpolate_bands(1)
-        fs = FermiSurface.from_band_structure(new_bs, kpoint_dim, wigner_seitz=False)
+        interpolator = FourierInterpolator(self.band_structure)
+        new_bs = interpolator.interpolate_bands(1)
+        fs = FermiSurface.from_band_structure(new_bs, wigner_seitz=False)
         plotter = FermiSurfacePlotter(fs)
         plot = plotter.get_plot(plot_type="matplotlib", spin=Spin.up)
         save_plot(plot, self.output_file)
